# Generated by roxygen2: do not edit by hand

S3method(applyFilt,RNAFilt)
S3method(applyFilt,customFilt)
S3method(applyFilt,cvFilt)
S3method(applyFilt,imdanovaFilt)
S3method(applyFilt,moleculeFilt)
S3method(applyFilt,proteomicsFilt)
S3method(applyFilt,rmdFilt)
S3method(applyFilt,totalCountFilt)
S3method(plot,RNAFilt)
S3method(plot,SPANSRes)
S3method(plot,corRes)
S3method(plot,customFilt)
S3method(plot,cvFilt)
S3method(plot,dataRes)
S3method(plot,dimRes)
S3method(plot,imdanovaFilt)
S3method(plot,isobaricnormRes)
S3method(plot,isobaricpepData)
S3method(plot,lipidData)
S3method(plot,metabData)
S3method(plot,moleculeFilt)
S3method(plot,naRes)
S3method(plot,nmrData)
S3method(plot,nmrnormRes)
S3method(plot,normRes)
S3method(plot,pepData)
S3method(plot,proData)
S3method(plot,proteomicsFilt)
S3method(plot,rmdFilt)
S3method(plot,seqData)
S3method(plot,statRes)
S3method(plot,totalCountFilt)
S3method(print,RNAFilt)
S3method(print,RNAFiltSummary)
S3method(print,customFilt)
S3method(print,customFilterSummary)
S3method(print,cvFilt)
S3method(print,cvFilterSummary)
S3method(print,dataRes)
S3method(print,imdanovaFilt)
S3method(print,imdanovaFilterSummary)
S3method(print,lipidData)
S3method(print,metabData)
S3method(print,moleculeFilt)
S3method(print,moleculeFilterSummary)
S3method(print,multiData)
S3method(print,normRes)
S3method(print,pepData)
S3method(print,proData)
S3method(print,proteomicsFilt)
S3method(print,proteomicsFilterSummary)
S3method(print,rmdFilt)
S3method(print,rmdFilterSummary)
S3method(print,seqData)
S3method(print,statRes)
S3method(print,totalCountFilt)
S3method(print,totalCountFiltSummary)
S3method(summary,RNAFilt)
S3method(summary,SPANSRes)
S3method(summary,corRes)
S3method(summary,customFilt)
S3method(summary,cvFilt)
S3method(summary,dimRes)
S3method(summary,imdanovaFilt)
S3method(summary,isobaricnormRes)
S3method(summary,lipidData)
S3method(summary,metabData)
S3method(summary,moleculeFilt)
S3method(summary,multiData)
S3method(summary,nmrData)
S3method(summary,nmrnormRes)
S3method(summary,normRes)
S3method(summary,pepData)
S3method(summary,proData)
S3method(summary,proteomicsFilt)
S3method(summary,rmdFilt)
S3method(summary,seqData)
S3method(summary,statRes)
S3method(summary,totalCountFilt)
S3method(summary,trelliData)
export("%>%")
export("%dopar%")
export(RNA_filter)
export(applyFilt)
export(as.isobaricpepData)
export(as.lipidData)
export(as.metabData)
export(as.multiData)
export(as.nmrData)
export(as.pepData)
export(as.proData)
export(as.seqData)
export(as.trelliData)
export(as.trelliData.edata)
export(bpquant)
export(combine_omicsData)
export(combine_techreps)
export(cor_result)
export(create_comparisonDF)
export(custom_filter)
export(custom_sampnames)
export(cv_filter)
export(diffexp_seq)
export(dim_reduction)
export(dispersion_est)
export(edata_replace)
export(edata_summary)
export(edata_transform)
export(fit_surv)
export(get_check_names)
export(get_comparisons)
export(get_data_class)
export(get_data_info)
export(get_data_norm)
export(get_data_scale)
export(get_data_scale_orig)
export(get_edata_cname)
export(get_emeta_cname)
export(get_fdata_cname)
export(get_filters)
export(get_group_DF)
export(get_group_table)
export(get_isobaric_info)
export(get_isobaric_norm)
export(get_meta_info)
export(get_nmr_info)
export(get_nmr_norm)
export(get_spans_params)
export(group_designation)
export(imd_anova)
export(imdanova_filter)
export(missingval_result)
export(molecule_filter)
export(normRes_tests)
export(normalize_global)
export(normalize_isobaric)
export(normalize_loess)
export(normalize_nmr)
export(normalize_quantile)
export(normalize_zero_one_scaling)
export(plot_km)
export(protein_quant)
export(proteomics_filter)
export(report_dataRes)
export(rmd_conversion)
export(rmd_filter)
export(set_check_names)
export(spans_procedure)
export(summary_km)
export(total_count_filter)
export(trelli_abundance_boxplot)
export(trelli_abundance_heatmap)
export(trelli_abundance_histogram)
export(trelli_foldchange_bar)
export(trelli_foldchange_boxplot)
export(trelli_foldchange_heatmap)
export(trelli_foldchange_volcano)
export(trelli_missingness_bar)
export(trelli_panel_by)
export(trelli_pvalue_filter)
export(trelli_rnaseq_boxplot)
export(trelli_rnaseq_heatmap)
export(trelli_rnaseq_histogram)
export(trelli_rnaseq_nonzero_bar)
exportClasses(statRes)
import(methods)
importFrom(Rcpp,evalCpp)
importFrom(dplyr,.data)
importFrom(foreach,"%dopar%")
importFrom(magrittr,"%>%")
importFrom(stats,anova)
importFrom(stats,aov)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,dist)
importFrom(stats,ecdf)
importFrom(stats,formula)
importFrom(stats,glm)
importFrom(stats,hclust)
importFrom(stats,lm)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,p.adjust.methods)
importFrom(stats,pbinom)
importFrom(stats,pchisq)
importFrom(stats,qchisq)
importFrom(stats,quantile)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,t.test)
importFrom(stats,var)
importFrom(utils,capture.output)
importFrom(utils,combn)
importFrom(utils,data)
importFrom(utils,head)
importFrom(utils,stack)
importFrom(utils,tail)
useDynLib(pmartR)
